@@ -49,7 +49,7 @@ static void fr_command_finalize    (GObject *object);
 GType
 fr_command_get_type ()
 {
-        static guint type = 0;
+        static GType type = 0;
 
         if (! type) {
                 GTypeInfo type_info = {
@@ -218,6 +218,7 @@ fr_command_init (FRCommand *comm)
 	comm->propExtractCanJunkPaths = FALSE;
 	comm->propPassword = FALSE;
 	comm->propTest = FALSE;
+	comm->propCanExtractAll = TRUE;
 }
 
 
